Supported Payment Providers
===========================

List of currently supported protocols:

 * IPizza
 * Solo/TUPAS

Providers supporting IPizza protocol
------------------------------------

* Supported Estonian banks:

    * `Danske Bank Estonia <https://danskebank.ee>`_ -
      :class:`wirexfers.providers.ipizza.EEDanskeProvider`
    * `Krediidipank <http://krediidipank.ee>`_ -
      :class:`wirexfers.providers.ipizza.EEKrediidipankProvider`
    * `LHV Bank Estonia <https://lhv.ee>`_ -
      :class:`wirexfers.providers.ipizza.EELHVProvider`
    * `SEB Bank Estonia <https://seb.ee>`_ -
      :class:`wirexfers.providers.ipizza.EESEBProvider`
    * `Swedbank Estonia <https://swedbank.ee>`_ -
      :class:`wirexfers.providers.ipizza.EESwedBankProvider`

Providers supporting Solo/TUPAS protocol
----------------------------------------

* Supported Estonian banks:

    * `Nordea Estonia <https://nordea.ee>`_ -
      :class:`wirexfers.providers.tupas.EENordeaProvider`
